Summary:        Video Multi-Method Assessment Fusion
Name:           vmaf
Version:        2.3.0
Release:        4%{?dist}
License:        BSD-2-Clause-Patent
URL:            https://github.com/netflix/vmaf
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc-c++ meson nasm vim-common
Requires:       libvmaf = %{version}-%{release}
# Needs AVX
ExclusiveArch:  x86_64

%description
VMAF is an Emmy-winning perceptual video quality assessment algorithm developed by Netflix.
This software package includes a stand-alone C library libvmaf and its wrapping Python
library. The Python library also provides a set of tools that allows a user to train and
test a custom VMAF model.
Also the command-line tool vmaf provides a complete algorithm implementation, such that
one can easily deploy VMAF in a production environment. Additionally, the vmaf tool
provides a number of auxillary features such as PSNR, SSIM and MS-SSIM.


%package -n     libvmaf
Summary:        Library for %{name}
Provides:       bundled(libsvm) = 3.24
Provides:       %{name}-static = %{version}-%{release}

%description -n libvmaf
Library for %{name}.


%package -n     libvmaf-devel
Summary:        Development files for %{name}
Requires:       libvmaf = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n libvmaf-devel
The %{name}-devel package contains libraries and header files for %{name}.


%package        models
Summary:        Model files for %{name}
Requires:       libvmaf = %{version}-%{release}
BuildArch:      noarch

%description    models
The %{name}-models package contains model files.
These are needed for apps that can't use the builtin models.


%prep
%autosetup -p1
rm -rf third_party/


%build
pushd libvmaf
%meson -Ddefault_library=shared
%meson_build
popd


%install
pushd libvmaf
%meson_install
popd

mkdir -p %{buildroot}%{rpmmacrodir}
cat > %{buildroot}%{rpmmacrodir}/macros.%{name} << EOF
%libvmaf_version %{version}
EOF
touch -r LICENSE %{buildroot}%{rpmmacrodir}/macros.%{name}

mkdir -p %{buildroot}%{_datadir}/model/
cp -Rp model/* %{buildroot}%{_datadir}/model/


%check
pushd libvmaf
ninja -vC %{_vpath_builddir} test ||:
popd


%files
%doc README.md
%{_bindir}/vmaf


%files -n libvmaf
%license LICENSE
%doc CHANGELOG.md
%{_libdir}/*.so.1*


%files -n libvmaf-devel
%doc CONTRIBUTING.md
%{rpmmacrodir}/macros.%{name}
%{_includedir}/libvmaf/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvmaf.pc


%files models
%{_datadir}/model/


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.3.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.3.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 2.3.0-2
- Fix description.

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 2.3.0-1
- Initial build
